@@ -539,18 +539,24 @@ otherprog:
 		  exit(EX_UNAVAILABLE);
 		}
 		if (vfd >= 0) {
+		  int sleeplimit = 260000; /* 260 000 seconds is circa 3d */
+
 		  if (fork() > 0) exit(EX_OK); /* Let the child to do
 						  the trace printout */
 		  if (vfd != 0) close(0);
 		  if (vfd != 1) close(1);
 		  vfp = fdopen(vfd, "r");
 		  while (vfp != NULL) {
-		    while (fgets(buf, sizeof buf, vfp) != NULL)
+		    while (fgets(buf, sizeof buf, vfp) != NULL) {
 		      fprintf(stderr, "%s", buf);
-		    if (strncmp(buf, "scheduler done", 14) == 0)
-		      break;
+		      if (strncmp(buf, "scheduler done", 14) == 0)
+			sleeplimit = 20; /* 20 seconds to death */
+		    }
 		    clearerr(vfp);
 		    sleep(1);
+		    --sleeplimit;
+		    if (sleeplimit < 0)
+		      break;
 		  }
 		}
 		if (verbfile)
