@@ -1,19 +1,40 @@
 #ifndef	__HOSTENV__
 #define	__HOSTENV__
 
-#include "libsupport.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_FCNTL_H
+# define FCNTL_H <fcntl.h>
+#endif
+
+#ifdef __GNUC__
+# define alloca __builtin_alloca
+# define USE_ALLOCA 1
+#else
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+#  define USE_ALLOCA 1
+# else
+#  ifdef _AIX
+ #pragma alloca
+#   define USE_ALLOCA 1
+#  else
+	/* no alloca() .. */
+#  endif
+# endif
+#endif
+
 #include <sys/types.h>
 #ifdef __linux__ /* Linux libc-4 needs this, libc-5 doesn't.. */
 # include <linux/limits.h>
 #endif
 #include <sys/param.h> /* Troublepotential: If somebody does not have it ? */
-#ifdef HAVE_ALLOCA_H
-# define USE_ALLOCA
-#endif
-#ifdef USE_UNISTD
+#ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
-#ifdef USE_STDLIB
+#ifdef HAVE_STDLIB_H
 # include <stdlib.h>
 #endif
 
