@@ -155,7 +155,7 @@ extern unsigned emsleeptime;
 extern int efstat __((int fd, struct stat *stbuf));
 extern int estat __((char *path, struct stat *stbuf));
 #endif
-extern long elseek __((int fd, long pos, int action));
+extern long elseek __((int fd, off_t pos, int action));
 extern int elink __((char *file1, char *file2));
 extern int eunlink __((char *file));
 extern int eclose __((int fd));
