@@ -102,6 +102,9 @@ uid_t ruid, euid;
 
 #ifdef	SYSV
 
+/* Uhh...  We open process uarea from kernel memory, and poke it
+   directly.  Seriously NOT FUN, but ...  */
+
 #include <stdio.h>
 #include <fcntl.h>
 #include <errno.h>
