@@ -42,12 +42,11 @@ char *sys_siglist[] = {
 #endif	/* HAVE_SYS_SIGLIST */
 
 #ifndef HAVE_STRSIGNAL
-#ifndef __FreeBSD__ /* Some systems can't stand this any which way.. */
-/* should propably use some other type for this variable.. */
-extern char *sys_siglist[];
+#ifndef HAVE_EXTERN_STR_SIGLIST
+extern const char *sys_siglist[];
 #endif
 
-char *strsignal(sig)
+const char *strsignal(sig)
      int sig;
 {
 	if (sig < 1 || sig > 31)
