@@ -9,7 +9,7 @@
 #include "mailer.h"
 #include "search.h"
 #include "io.h"
-#ifdef	USE_YP
+#ifdef	HAVE_YP
 #include <rpc/rpc.h>
 #include <netdb.h>
 #include <sys/socket.h>
@@ -122,4 +122,4 @@ print_yp(sip, outfp)
 {
 	return;
 }
-#endif	/* USE_YP */
+#endif	/* HAVE_YP */
