@@ -13,6 +13,7 @@
 #include <sys/file.h>
 #include <errno.h>
 #include "mail.h"
+#include "libz.h"
 #ifdef	HAVE_SYSLOG
 #include <syslog.h>
 #endif	/* HAVE_SYSLOG */
@@ -49,10 +50,8 @@ extern int elink();
 extern int eunlink();
 extern int erename();
 extern int getline();
-extern int repos_getline();
 extern int nobody;
 extern int s_equal();
-extern long elseek();
 extern long offset();
 extern void initline();
 
@@ -679,7 +678,7 @@ reject(e, msgfile)
 	    break;
 	}
 	fputs("env-end\n",mfp);
-	fseek(fp,0,0);
+	fseek(fp,(off_t)0,0);
 
 	/* who is it from? */
 	cp = h->h_pname;
@@ -1858,7 +1857,7 @@ sequencer(e, file)
 		setreuid(0, e->e_statbuf.st_uid);
 
 		if ((vfp = fopen(verbosefile, "a")) != NULL) {
-			fseek(vfp, 0L, 2);
+			fseek(vfp, (off_t)0, 2);
 			setvbuf(vfp, NULL, _IOLBF, 0);
 			fprintf(vfp, "router processed message %s\n", file);
 			fprintf(ofp, "%c%c%s\n", _CF_VERBOSE, _CFTAG_NORMAL,
