@@ -7,6 +7,12 @@
  *	Matti Aarnio <mea@nic.funet.fi>  (copyright) 1992-1995
  */
 
+/*
+ * This program must be installed suid to the uid the scheduler runs as
+ * (usually root).  Unfortunately.
+ */
+
+
 #include "hostenv.h"
 #include <stdio.h>
 #include <ctype.h>
@@ -62,16 +68,15 @@ extern void printaddrs();
 extern void prversion(), checkrouter(), checkscheduler();
 extern void report();
 
-
-/*
- * This program must be installed suid to the uid the scheduler runs as
- * (usually root).  Unfortunately.
- */
+#ifndef strchr
+extern char *strchr(), *strrchr();
+#endif
 
 char	*progname;
 char	*postoffice;
 
 int	debug, verbose, summary, user, status, onlyuser, nonlocal, schedq;
+int	sawcore, othern;
 
 time_t	now;
 
@@ -476,26 +481,22 @@ checkrouter()
 	  printf("%d message%s deferred\n", n, n != 1 ? "s" : "");
 }
 
-void
-checkscheduler()
+
+int countfiles(dirpath)
+char *dirpath;
 {
-	int pid, n, tn, r, sawcore = 0;
-	FILE *fp;
+	char path[512];
+
 	struct dirent *dp;
 	DIR *dirp;
+	int n = 0;
 
-	if (postoffice == NULL)
-	  return;
-
-	sprintf(path, "%s/%s", postoffice, TRANSPORTDIR);
-	if ((dirp = opendir(path)) == NULL) {
+	if ((dirp = opendir(dirpath)) == NULL) {
 	  fprintf(stderr, "%s: opendir(%s):", progname, path);
 	  perror(" ");
 	  return;
 	}
-	sawcore = 0;
-	tn = 0;
-	for (dp = readdir(dirp), n = 0; dp != NULL; dp = readdir(dirp)) {
+	for (dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
 	  if (dp->d_name[0] == '.' &&
 	      (dp->d_name[1] == 0 || (dp->d_name[1] == '.' &&
 				      dp->d_name[2] == 0)))
@@ -503,9 +504,22 @@ checkscheduler()
 	  if (isascii(dp->d_name[0]) && isdigit(dp->d_name[0]))
 	    ++n;
 	  else if (strcmp("core",dp->d_name)==0)
-	    sawcore = 1, ++tn;
-	  else
-	    ++tn;
+	    sawcore = 1, ++othern;
+	  else {
+	    if (dp->d_name[0] >= 'A' && dp->d_name[0] <= 'Z' &&
+		dp->d_name[1] == 0) {
+	      struct stat stbuf;
+	      sprintf(path, "%s/%s", dirpath, dp->d_name);
+	      if (lstat(path,&stbuf) != 0 ||
+		  !S_ISDIR(stbuf.st_mode)) {
+		++othern;
+	      } else {
+		n += countfiles(path);
+	      }
+	    } else {
+	      ++othern;
+	    }
+	  }
 	}
 #ifdef	BUGGY_CLOSEDIR
 	/*
@@ -516,6 +530,28 @@ checkscheduler()
 	close(dirp->dd_fd);
 #endif
 	closedir(dirp);
+	return n;
+}
+
+
+void
+checkscheduler()
+{
+	int pid, n, r;
+	FILE *fp;
+	struct dirent *dp;
+	DIR *dirp;
+
+	if (postoffice == NULL)
+	  return;
+
+	sawcore = 0;
+	othern  = 0;
+
+	sprintf(path, "%s/%s", postoffice, TRANSPORTDIR);
+
+	n = countfiles(path);
+
 	printf("%d message%s in transport queue: ",
 	       n, n != 1 ? "s" : "");
 
@@ -579,6 +615,7 @@ isalive(pidfile, pidp, fpp)
 #define	MAGIC_PREAMBLE		"version "
 #define	LEN_MAGIC_PREAMBLE	(sizeof MAGIC_PREAMBLE - 1)
 #define	VERSION_ID		"zmailer 1.0"
+#define	VERSION_ID2		"zmailer 2.0"
 #define	GETLINE(buf,fp)		\
 	if (fgets(buf, bufsize, fp) == NULL) {\
 		fprintf(stderr, "%s: no input from scheduler\n", progname);\
@@ -619,6 +656,11 @@ parse(fp)
 	buf = emalloc(bufsize);
 
 	GETLINE(buf,fp);
+
+	if (EQNSTR(buf, MAGIC_PREAMBLE) &&
+	    EQNSTR(buf+LEN_MAGIC_PREAMBLE, VERSION_ID2))
+	  return 2; /* We have version 2 scheduler! */
+
 	if (!(EQNSTR(buf, MAGIC_PREAMBLE)
 	      && EQNSTR(buf+LEN_MAGIC_PREAMBLE, VERSION_ID))) {
 	  fprintf(stderr, "%s: version mismatch, input is \"%s\".\n", progname, buf);
@@ -881,18 +923,48 @@ repscan(spl)
 	return 0;
 }
 
+void query2(fp)
+	FILE *fp;
+{
+	int rc, len;
+	char buf[512];
+
+	if (schedq) {
+	  if (schedq > 1)
+	    strcpy(buf,"SHOW-QUEUE CONDENCED\n");
+	  else
+	    strcpy(buf,"SHOW-QUEUE THREADS\n");
+	  len = strlen(buf);
+	  if (write(fileno(fp),buf,len) != len) {
+	    perror("write to scheduler command interface failed");
+	    return;
+	  }
+	  while (!feof(fp) && !ferror(fp)) {
+	    int c = getc(fp);
+	    if (c == EOF) break;
+	    putc(c,stdout);
+	  }
+	} else {
+	  printf("Sorry, scheduler with protocol version 2 can't give results without -Q option\n");
+	}
+}
+
 void
 report(fp)
 	FILE *fp;
 {
-	if (!parse(fp))
+	int rc = parse(fp);
+	if (rc == 0)
 	  return;
+	if (rc == 2) {
+	  query2(fp);
+	}
 	if (schedq) {
 	  char linebuf[4000];
 	  while (!feof(fp) && !ferror(fp)) {
 	    if (fgets(linebuf,sizeof(linebuf),fp) == NULL)
 	      break;
-	    if (schedq > 1 && linebuf[0] == '\t' && linebuf[1] != '\t')
+	    if (schedq > 1 && linebuf[0] == ' ')
 	      continue;
 	    fputs(linebuf,stdout);
 	  }
