@@ -1022,7 +1022,7 @@ static struct ctlfile *schedule(fd, file, cehead, ino)
 	for (vp = cfp->head; vp != NULL; vp = vp->next[L_CTLFILE]) {
 	  vtxdo(vp, cehead, file);
 	  if (cfp->vfp)
-	    fseek(cfp->vfp, 0, 2);
+	    fseek(cfp->vfp, (off_t)0, 2);
 	}
 	/* If no verbose trace, don't keep contents in core!
 	   this means HUGE memory save at busy machines! */
@@ -1419,7 +1419,7 @@ static struct ctlfile *vtxprep(cfp, file)
 	      setreuid(0, 0);
 
 	      if (cfp->vfp != NULL) {
-		fseek(cfp->vfp, (long)0, 2);
+		fseek(cfp->vfp, (off_t)0, 2);
 		setvbuf(cfp->vfp, (char *)NULL,	_IOLBF, 0);
 	      }
 	      if (cfp->vfp != NULL && cfp->mid != NULL)
@@ -1983,7 +1983,7 @@ static void init_timeserver()
 	memset(blk,0,sizeof(blk));
 	for (i=0; i < MAPSIZE; i += sizeof(blk))
 	  write(fd,blk,sizeof(blk));
-	lseek(fd,0,0);
+	lseek(fd,(off_t)0,0);
 
 #ifndef MAP_FILE
 # define MAP_FILE 0 /* SunOS 4.1 does not have this */
