@@ -253,7 +253,7 @@ unctlfile(cfp, no_unlink)
 	    printf("   and %s/\n", path);
 
 	  if (cfp->vfp != NULL) {
-	    fseek(cfp->vfp, 0, 2);
+	    fseek(cfp->vfp, (off_t)0, 2);
 	    fprintf(cfp->vfp,
 		    "scheduler done processing %s\n", cfp->mid);
 	    fclose(cfp->vfp);
@@ -675,7 +675,7 @@ static int u_ok(vp, index, inum, offset, notary, message)
 	/* printf("%s: %d/%d/%s/ok %s\n", vp->cfp->logident, inum, offset,
 	   notary, message ? message : "-"); */
 	if (vp->cfp->vfp != NULL && vp->cfp->contents != NULL) {
-	  fseek(vp->cfp->vfp, 0, 2);
+	  fseek(vp->cfp->vfp, (off_t)0, 2);
 	  fprintf(vp->cfp->vfp, "%s: ok %s\n",
 		  vp->cfp->contents + offset + 2 + _CFTAG_RCPTPIDSIZE,
 		  message == NULL ? "(sent)" : message);
@@ -709,7 +709,7 @@ static int u_deferred(vp, index, inum, offset, notary, message)
 	}
 
 	if (vp->cfp->vfp != NULL && vp->cfp->contents != NULL) {
-	  fseek(vp->cfp->vfp, 0, 2);
+	  fseek(vp->cfp->vfp, (off_t)0, 2);
 	  fprintf(vp->cfp->vfp, "%s: deferred %s\n",
 		  vp->cfp->contents + offset + 2 + _CFTAG_RCPTPIDSIZE,
 		  message == NULL ? "(unknown)" : message);
@@ -738,7 +738,7 @@ static int u_error(vp, index, inum, offset, notary, message)
 	msgerror(vp, offset, message);
 
 	if (vp->cfp->vfp != NULL && vp->cfp->contents != NULL) {
-	  fseek(vp->cfp->vfp, 0, 2);
+	  fseek(vp->cfp->vfp, (off_t)0, 2);
 	  fprintf(vp->cfp->vfp, "%s: error %s\n",
 		  vp->cfp->contents + offset + 2 + _CFTAG_RCPTPIDSIZE,
 		  message);
@@ -789,7 +789,7 @@ static int u_retryat(vp, index, inum, offset, notary, message)
 	}
 
 	if (vp->cfp->vfp != NULL && vp->cfp->contents != NULL) {
-	  fseek(vp->cfp->vfp, 0, 2);
+	  fseek(vp->cfp->vfp, (off_t)0, 2);
 	  fprintf(vp->cfp->vfp, "%s: retryat %d %s\n",
 		  vp->cfp->contents + offset + 2 + _CFTAG_RCPTPIDSIZE,
 		  (int)retrytime, message == NULL ? "(unknown)" : message);
