@@ -2039,7 +2039,7 @@ smtpserver(insecure)
 	}
 	if (mfp != NULL)
 	  mail_abort(mfp);
-	reporterr(lseek(0,0,SEEK_CUR), "session terminated");
+	reporterr(lseek(0,(off_t)0,SEEK_CUR), "session terminated");
 }
 
 #define	TYPE_(m)	type(-214, NULL, "%s", m);
