@@ -242,7 +242,7 @@ process(dp)
 	    else
 	      break;
 	  }
-	  fseek(efp,0,0); /* Rewind! */
+	  fseek(efp,(off_t)0,0); /* Rewind! */
 	  fputs("env-end\n",mfp);
 
 	  /* copy To: from error return address */
@@ -344,7 +344,7 @@ process(dp)
 	rp = dp->recipients;
 	/* copy original message file */
 	/* seek to message body -- try it anyway */
-	lseek(dp->msgfd, dp->msgbodyoffset, 0 /* L_SET -- usually */);
+	lseek(dp->msgfd, (off_t)(dp->msgbodyoffset), 0 /* L_SET -- usually */);
 	/* write the (new) headers with local "Received:"-line.. */
 	writeheaders(rp,mfp,"\n",0,0);
 
