@@ -277,7 +277,7 @@ process(dp)
 	if (!sawok)
 	  return;
 
-	if (lseek(dp->msgfd, dp->msgbodyoffset, L_SET) < 0L)
+	if (lseek(dp->msgfd, (off_t)(dp->msgbodyoffset), L_SET) < 0L)
 	  warning("Cannot seek to message body! (%m)", (char *)NULL);
 
 	setreuid(-1, atoi(dp->senders->misc));
