@@ -568,7 +568,7 @@ process(dp)
 
 	for (rp = dp->recipients; rp != NULL; rp = rp->next) {
 	  /* seek to message body start on each iteration */
-	  if (lseek(dp->msgfd, dp->msgbodyoffset, L_SET) < 0L) {
+	  if (lseek(dp->msgfd, (off_t)dp->msgbodyoffset, L_SET) < 0L) {
 	    warning("Cannot seek to message body in %s! (%m)",
 		    dp->msgfile);
 	    DIAGNOSTIC(rp, EX_TEMPFAIL,
@@ -624,15 +624,17 @@ propably_x400(addr)
 int havedotlock = 0, havemaillock = 0;
 
 int
-acquire_mboxlock(rp,file)
+acquire_mboxlock(rp,file,uid)
 struct rcpt *rp;
 char *file;
+uid_t uid;
 {
 #ifdef	HAVE_MAILLOCK_H
 	char *maillockuser;
 	struct passwd *pw;
 	int i;
 	char errbuf[30];
+	char *cp;
 
 	if (*(rp->addr->user) == TO_FILE) {
 	  if ((pw = getpwuid(uid)) == NULL) {
@@ -730,7 +732,7 @@ char *file;
 {
 #if defined(HAVE_LOCKF) && defined(F_LOCK)
 	/* Seek to begining for locking! [mea@utu.fi] */
-	if (lseek(fdmail, 0L, L_SET) < 0 ||
+	if (lseek(fdmail, (off_t)0, L_SET) < 0 ||
 	    lockf(fdmail, F_LOCK, 0) < 0) {
 	  alarm(0);
 	  notaryreport(file,"delayed",
@@ -740,7 +742,7 @@ char *file;
 		     "can't lockf() \"%s\"", file);
 	  return 1;
 	}
-	lseek(fdmail, 0L, L_XTND); /* To the end of the file */
+	lseek(fdmail, (off_t)0, L_XTND); /* To the end of the file */
 #endif	/* HAVE_LOCKF */
 	return 0;
 }
@@ -1094,7 +1096,7 @@ deliver(dp, rp, timestring)
 		break;
 	      case '.':
 		if (ismbox)
-		  err = acquire_mboxlock(rp,file);
+		  err = acquire_mboxlock(rp,file,uid);
 		break;
 	      case 'N':
 	      case 'n':
@@ -1143,7 +1145,7 @@ deliver(dp, rp, timestring)
 	        case 'L':
 		case 'l':
 #if defined(HAVE_LOCKF) && defined(F_LOCK) /* If one, also the other */
-		  lseek(fdmail,0L,L_SET);
+		  lseek(fdmail,(off_t)0,L_SET);
 		  lockf(fdmail, F_ULOCK, 0);
 #endif	/* HAVE_LOCKF */
 		  break;
@@ -1169,7 +1171,7 @@ deliver(dp, rp, timestring)
 
 
 	/* Where is the end of file -- before we write anything */
-	eofindex = lseek(fdmail, 0L, L_XTND);
+	eofindex = lseek(fdmail, (off_t)0, L_XTND);
 #if	defined(HAVE_SOCKET)
 	if (nbp != NULL)
 	  nbp->offset = eofindex;
@@ -1214,7 +1216,7 @@ deliver(dp, rp, timestring)
 	    case 'L':
 	    case 'l':
 #if defined(HAVE_LOCKF) && defined(F_LOCK)
-	      lseek(fdmail,0L,L_SET);
+	      lseek(fdmail,(off_t)0,L_SET);
 	      lockf(fdmail, F_ULOCK, 0);
 #endif	/* HAVE_LOCKF */
 	      break;
@@ -1294,7 +1296,7 @@ putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	} else if (eofindex > 0L && eofindex < (sizeof "From x\n")) {
 	  /* A mail message *cannot* be this small.  It must be
 	     a corrupted mailbox file.  Ignore the trash bytes. */
-	  fseek(fp, 0L, L_SET);
+	  fseek(fp, (off_t)0, L_SET);
 	  eofindex = 0;
 	}
 
@@ -1341,7 +1343,7 @@ putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	  /* XX: should I really do this? */
 	  fflush(fp);
 	  if (eofindex >= 0)
-	    ftruncate(FILENO(fp), (u_long)eofindex);
+	    ftruncate(FILENO(fp), (off_t)eofindex);
 #endif
 	  fclose(fp);
 	  fp = NULL;
@@ -1359,9 +1361,9 @@ putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	 * login etc. can distinguish new mail from old.
 	 * The mtime will be set to now by the following write() calls.
 	 */
-	fseek(fp, -2L, L_XTND);
+	fseek(fp, (off_t)-2, L_XTND);
 	len = fread(buf, 1, 2, fp);
-	fseek(fp, 0L, L_XTND);	/* to end of file, again */
+	fseek(fp, (off_t)0, L_XTND);	/* to end of file, again */
 
 	if (len == 1 || len == 2) {
 	  --len;
@@ -1376,7 +1378,7 @@ putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	    /* XX: should I really do this? */
 	    fflush(fp);
 	    if (eofindex >= 0)
-	      ftruncate(FILENO(fp), (u_long)eofindex);
+	      ftruncate(FILENO(fp), (off_t)eofindex);
 #endif /* HAVE_FTRUNCATE */
 	    fclose(fp);
 	    fp = NULL;
