@@ -316,7 +316,7 @@ deliver(dp, mp, startrp, endrp, verboselog)
 	int	status;
 	int content_kind, conversion_prohibited, convertmode, ascii_clean = 0;
 
-	if (lseek(dp->msgfd, dp->msgbodyoffset, L_SET) < 0L)
+	if (lseek(dp->msgfd, (off_t)(dp->msgbodyoffset), L_SET) < 0L)
 		warning("Cannot seek to message body! (%m)", (char *)NULL);
 
 	i = 0;
@@ -696,7 +696,7 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 	  char iobuf[BUFSIZ];
 	  FILE *mfp = fdopen(mfd,"r");
 
-	  fseek(mfp,dp->msgbodyoffset,L_SET);
+	  fseek(mfp,(off_t)(dp->msgbodyoffset),L_SET);
 
 	  setvbuf(mfp, iobuf, _IOFBF, sizeof(iobuf));
 
@@ -712,7 +712,7 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 	  /*
 	     if(verboselog) fprintf(verboselog,
 	     "sm: Convert mode: %d, fd=%d, fdoffset=%d, bodyoffset=%d\n",
-	     convertmode, mfd, (int)lseek(mfd,0,1),
+	     convertmode, mfd, (int)lseek(mfd,(off_t)0,1),
 	     dp->msgbodyoffset);
 	   */
 
@@ -1144,7 +1144,7 @@ struct ctldesc *dp;
 	register int i;
 	register int bufferfull;
 	int lastwasnl;
-	long mfd_pos;
+	off_t mfd_pos;
 	int mfd = dp->msgfd;
 
 /* can we use cache of message body data */
