@@ -159,8 +159,6 @@ char ipaddress[30];
 char errormsg[BUFSIZ];
 char *progname;
 char *cmdline, *eocmdline, *logfile, *msgfile;
-char *myaddrs = NULL;
-int nmyaddrs = 0;
 int pid;
 int debug = 0;
 int verbosity = 0;
@@ -243,6 +241,8 @@ extern char *dottedquad();
 extern char *optarg;
 extern int optind;
 
+extern char **environ;
+
 extern int deliver __((struct ctldesc *dp, FILE *smtpfp[2], FILE *verboselog, struct rcpt *startrp, struct rcpt *endrp));
 extern int writebuf __((FILE *fp, char *buf, int len));
 extern int writemimeline __((FILE *fp, char *buf, int len, int convertmode, int*lastchp));
@@ -281,7 +281,7 @@ extern int matchroutermxes __((char*,struct address*));
 extern RETSIGTYPE sig_pipe __((int));
 extern RETSIGTYPE sig_alarm __((int));
 extern int getmyhostname();
-extern void stashmyaddresses();
+extern void stachmyaddresses();
 extern int cistrcmp(), cistrncmp();
 extern void getdaemon();
 
@@ -322,10 +322,9 @@ static char *logtag()
 }
 
 int
-main(argc, argv, envp)
+main(argc, argv)
 	int argc;
 	char *argv[];
-	char *envp[];
 {
 	char file[MAXPATHLEN+128];
 	char *channel = NULL, *host = NULL;
@@ -352,8 +351,8 @@ main(argc, argv, envp)
 	for (i = 0; i < argc; ++i)
 	  eocmdline += strlen(argv[i]) + 1;
 	/* Can overwrite also the environment strings.. */
-	for (i = 0; envp[i] != NULL; ++i)
-	  eocmdline += strlen(envp[i]) + 1;
+	for (i = 0; environ[i] != NULL; ++i)
+	  eocmdline += strlen(environ[i]) + 1;
 
 	SIGNAL_HANDLESAVE(SIGINT, SIG_IGN, oldsig);
 	if (oldsig != SIG_IGN)
@@ -477,8 +476,8 @@ main(argc, argv, envp)
 	  /* Default it only when not having an explicite value
 	     in it..   James S MacKinnon <jmack@Phys.UAlberta.Ca> */
 	  getmyhostname(myhostname, sizeof myhostname);
-	  stashmyaddresses(myhostname);
 	}
+	stachmyaddresses(myhostname);
 
 	if (conndebug && !debug && host) {
 	  firstmx = 0;
@@ -1166,7 +1165,7 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 #endif /* !HAVE_MMAP */
 #endif /* 0 */
 
-	if (lseek(dp->msgfd, dp->msgbodyoffset, SEEK_SET) < 0L)
+	if (lseek(dp->msgfd, (off_t)dp->msgbodyoffset, SEEK_SET) < 0L)
 	  warning("Cannot seek to message body! (%m)", (char *)NULL);
 
 	bufferfull = 0;
@@ -2983,79 +2982,6 @@ report(va_alist)
 	va_end(ap);
 }
 
-void
-stashmyaddresses(host)
-	char *host;
-{
-	int naddrs;
-	struct hostent *hp;
-
-	if ((hp = gethostbyname(host)) == NULL)
-	  return;
-
-	naddrs = 0;
-	for (hp_init(hp); *hp_getaddr() != NULL; hp_nextaddr())
-	  ++naddrs;
-	nmyaddrs = naddrs;
-	if ((myaddrs = (char *)malloc(nmyaddrs * hp->h_length)) == NULL)
-	  return;
-	for (hp_init(hp); *hp_getaddr() != NULL; hp_nextaddr())
-	  memcpy(&myaddrs[(--naddrs)*hp->h_length], *hp_getaddr(), hp->h_length);
-}
-
-
-int
-matchmyaddress(addr,len)
-	char *addr;
-	int len;
-{
-	int i;
-	unsigned int ia; /* 32 bit address */
-
-	if (!myaddrs) return 0; /* Don't know my addresses ! */
-	
-	for (i = 0; i < nmyaddrs; ++i) {
-	  /* if this is myself, skip to next MX host */
-	  if (memcmp(addr, &myaddrs[i*len],len) == 0)
-	    return 1;
-	}
-	/* Also match loopback net.. */
-	if (len == 4) {
-	  memcpy(&ia,addr,4);
-#ifndef INADDR_LOOPBACK /* FreeBSD does not have this in  <netinet/in.h> ! */
-# define INADDR_LOOPBACK 0x7f000001
-#endif
-	  if (IN_CLASSA(ntohl(ia)) &&
-	      (ntohl(ia) & IN_CLASSA_NET) == (IN_CLASSA_NET & INADDR_LOOPBACK)) {
-	    return 2;
-	  }
-	}
-	return 0;
-}
-
-int
-matchmyaddresses(hp)
-	struct hostent *hp;
-{
-	char **alist;
-	int i;
-#ifndef	h_addr	/* no h_addr macro -- presumably 4.2BSD or earlier.. */
-	char *fakealist[2];
-
-	alist = fakealist;
-	fakealist[0] = hp->h_addr;
-	fakealist[1] = NULL;
-#else
-	alist = hp->h_addr_list;
-#endif
-	while (alist && *alist) {
-	  if ((i = matchmyaddress(*alist,hp->h_length)))
-	    return i;
-	  ++alist;
-	}
-	return 0;
-}
-
 #ifdef	BIND
 
 typedef union {
@@ -3412,7 +3338,7 @@ struct ctldesc *dp;
 	register int i;
 	register int bufferfull;
 	int lastwasnl;
-	long mfd_pos;
+	off_t mfd_pos;
 	int mfd = dp->msgfd;
 
 	/* can we use cache of message body data ? */
@@ -3425,7 +3351,7 @@ struct ctldesc *dp;
 	/* we are assumed to be positioned properly at start of message body */
 	bufferfull = 0;
 
-	mfd_pos = lseek(mfd, dp->msgbodyoffset, SEEK_SET);
+	mfd_pos = lseek(mfd, (off_t)dp->msgbodyoffset, SEEK_SET);
 	
 	while ((i = read(mfd, let_buffer, sizeof let_buffer)) != 0) {
 	  if (i < 0) {
